@@ -1,7 +1,6 @@
 package util
 
 import (
-	"bufio"
 	"bytes"
 	"context"
 	"encoding/base64"
@@ -17,6 +16,9 @@ import (
 	"strings"
 	"time"
 
+	clientcorev1 "k8s.io/client-go/kubernetes/typed/core/v1"
+
+	yaml "gopkg.in/yaml.v2"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/client-go/dynamic"
 
@@ -70,6 +72,7 @@ type CLI struct {
 	verb               string
 	configPath         string
 	adminConfigPath    string
+	token              string
 	username           string
 	globalArgs         []string
 	commandArgs        []string
@@ -107,8 +110,9 @@ func NewCLIWithFramework(kubeFramework *framework.Framework) *CLI {
 // namespace. Should be called outside of a Ginkgo .It() function.
 func NewCLI(project string) *CLI {
 	cli := NewCLIWithoutNamespace(project)
+	cli.withoutNamespace = false
 	// create our own project
-	g.BeforeEach(cli.SetupProject)
+	g.BeforeEach(func() { _ = cli.SetupProject() })
 	return cli
 }
 
@@ -126,9 +130,10 @@ func NewCLIWithoutNamespace(project string) *CLI {
 				ClientBurst: 50,
 			},
 		},
-		username:        "admin",
-		execPath:        "oc",
-		adminConfigPath: KubeConfigPath(),
+		username:         "admin",
+		execPath:         "oc",
+		adminConfigPath:  KubeConfigPath(),
+		withoutNamespace: true,
 	}
 	g.AfterEach(cli.TeardownProject)
 	g.AfterEach(cli.kubeFramework.AfterEach)
@@ -196,9 +201,35 @@ func (c CLI) WithoutNamespace() *CLI {
 	return &c
 }
 
+// WithToken instructs the command should be invoked with --token rather than --kubeconfig flag
+func (c CLI) WithToken(token string) *CLI {
+	c.configPath = ""
+	c.token = token
+	return &c
+}
+
+// SetupNamespace creates a namespace, without waiting for any resources except the SCC annotation to be available
+func (c *CLI) SetupNamespace() string {
+	requiresTestStart()
+	newNamespace := names.SimpleNameGenerator.GenerateName(fmt.Sprintf("e2e-test-%s-", c.kubeFramework.BaseName))
+	c.SetNamespace(newNamespace)
+
+	framework.Logf("Creating namespace %q", newNamespace)
+	_, err := c.AdminKubeClient().CoreV1().Namespaces().Create(context.Background(), &corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{Name: newNamespace},
+	}, metav1.CreateOptions{})
+	o.Expect(err).NotTo(o.HaveOccurred())
+
+	c.kubeFramework.AddNamespacesToDelete(&corev1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: newNamespace}})
+
+	WaitForNamespaceSCCAnnotations(c.AdminKubeClient().CoreV1(), newNamespace)
+	return newNamespace
+}
+
 // SetupProject creates a new project and assign a random user to the project.
 // All resources will be then created within this project.
-func (c *CLI) SetupProject() {
+// Returns the name of the new project.
+func (c *CLI) SetupProject() string {
 	requiresTestStart()
 	newNamespace := names.SimpleNameGenerator.GenerateName(fmt.Sprintf("e2e-test-%s-", c.kubeFramework.BaseName))
 	c.SetNamespace(newNamespace).ChangeUser(fmt.Sprintf("%s-user", newNamespace))
@@ -276,9 +307,10 @@ func (c *CLI) SetupProject() {
 		o.Expect(err).NotTo(o.HaveOccurred())
 	}
 
-	WaitForNamespaceSCCAnnotations(c.ProjectClient().ProjectV1(), newNamespace)
+	WaitForProjectSCCAnnotations(c.ProjectClient().ProjectV1(), newNamespace)
 
 	framework.Logf("Project %q has been fully provisioned.", newNamespace)
+	return newNamespace
 }
 
 func (c *CLI) setupSelfProvisionerRoleBinding() error {
@@ -515,9 +547,13 @@ func (c *CLI) Run(commands ...string) *CLI {
 		adminConfigPath: c.adminConfigPath,
 		configPath:      c.configPath,
 		username:        c.username,
-		globalArgs: append([]string{
-			fmt.Sprintf("--kubeconfig=%s", c.configPath),
-		}, commands...),
+		globalArgs:      commands,
+	}
+	if len(c.configPath) > 0 {
+		nc.globalArgs = append([]string{fmt.Sprintf("--kubeconfig=%s", c.configPath)}, nc.globalArgs...)
+	}
+	if len(c.configPath) == 0 && len(c.token) > 0 {
+		nc.globalArgs = append([]string{fmt.Sprintf("--token=%s", c.token)}, nc.globalArgs...)
 	}
 	if !c.withoutNamespace {
 		nc.globalArgs = append([]string{fmt.Sprintf("--namespace=%s", c.Namespace())}, nc.globalArgs...)
@@ -526,18 +562,6 @@ func (c *CLI) Run(commands ...string) *CLI {
 	return nc.setOutput(c.stdout)
 }
 
-// Template sets a Go template for the OpenShift CLI command.
-// This is equivalent of running "oc get foo -o template --template='{{ .spec }}'"
-func (c *CLI) Template(t string) *CLI {
-	if c.verb != "get" {
-		FatalErr("Cannot use Template() for non-get verbs.")
-	}
-	templateArgs := []string{"--output=template", fmt.Sprintf("--template=%s", t)}
-	commandArgs := append(c.commandArgs, templateArgs...)
-	c.finalArgs = append(c.globalArgs, commandArgs...)
-	return c
-}
-
 // InputString adds expected input to the command
 func (c *CLI) InputString(input string) *CLI {
 	c.stdin.WriteString(input)
@@ -547,7 +571,6 @@ func (c *CLI) InputString(input string) *CLI {
 // Args sets the additional arguments for the OpenShift CLI command
 func (c *CLI) Args(args ...string) *CLI {
 	c.commandArgs = args
-	c.finalArgs = append(c.globalArgs, c.commandArgs...)
 	return c
 }
 
@@ -563,52 +586,55 @@ type ExitError struct {
 
 // Output executes the command and returns stdout/stderr combined into one string
 func (c *CLI) Output() (string, error) {
-	if c.verbose {
-		fmt.Printf("DEBUG: oc %s\n", c.printCmd())
-	}
-	cmd := exec.Command(c.execPath, c.finalArgs...)
-	cmd.Stdin = c.stdin
-	framework.Logf("Running '%s %s'", c.execPath, strings.Join(c.finalArgs, " "))
-	out, err := cmd.CombinedOutput()
-	trimmed := strings.TrimSpace(string(out))
-	switch err.(type) {
-	case nil:
-		c.stdout = bytes.NewBuffer(out)
-		return trimmed, nil
-	case *exec.ExitError:
-		// avoid excessively long lines in the error output if a command generates a giant amount of logging
-		const maxLength = 809
-		shortened := trimmed
-		if len(shortened) > maxLength {
-			shortened = shortened[:maxLength/2] + "\n...\n" + shortened[len(shortened)-(maxLength/2):]
-		}
-		framework.Logf("Error running %v:\n%s", cmd, shortened)
-		return trimmed, &ExitError{ExitError: err.(*exec.ExitError), Cmd: c.execPath + " " + strings.Join(c.finalArgs, " "), StdErr: shortened}
-	default:
-		FatalErr(fmt.Errorf("unable to execute %q: %v", c.execPath, err))
-		// unreachable code
-		return "", nil
-	}
+	var buff bytes.Buffer
+	_, _, err := c.outputs(&buff, &buff)
+	return strings.TrimSpace(string(buff.Bytes())), err
 }
 
 // Outputs executes the command and returns the stdout/stderr output as separate strings
 func (c *CLI) Outputs() (string, string, error) {
+	var stdOutBuff, stdErrBuff bytes.Buffer
+	return c.outputs(&stdOutBuff, &stdErrBuff)
+}
+
+// Background executes the command in the background and returns the Cmd object
+// which may be killed later via cmd.Process.Kill().  It also returns buffers
+// holding the stdout & stderr of the command, which may be read from only after
+// calling cmd.Wait().
+func (c *CLI) Background() (*exec.Cmd, *bytes.Buffer, *bytes.Buffer, error) {
+	var stdOutBuff, stdErrBuff bytes.Buffer
+	cmd, err := c.start(&stdOutBuff, &stdErrBuff)
+	return cmd, &stdOutBuff, &stdErrBuff, err
+}
+
+func (c *CLI) start(stdOutBuff, stdErrBuff *bytes.Buffer) (*exec.Cmd, error) {
+	c.finalArgs = append(c.globalArgs, c.commandArgs...)
 	if c.verbose {
 		fmt.Printf("DEBUG: oc %s\n", c.printCmd())
 	}
 	cmd := exec.Command(c.execPath, c.finalArgs...)
 	cmd.Stdin = c.stdin
 	framework.Logf("Running '%s %s'", c.execPath, strings.Join(c.finalArgs, " "))
-	//out, err := cmd.CombinedOutput()
-	var stdErrBuff, stdOutBuff bytes.Buffer
-	cmd.Stdout = &stdOutBuff
-	cmd.Stderr = &stdErrBuff
-	err := cmd.Run()
+
+	cmd.Stdout = stdOutBuff
+	cmd.Stderr = stdErrBuff
+	err := cmd.Start()
+
+	return cmd, err
+}
+
+func (c *CLI) outputs(stdOutBuff, stdErrBuff *bytes.Buffer) (string, string, error) {
+	cmd, err := c.start(stdOutBuff, stdErrBuff)
+	if err != nil {
+		return "", "", err
+	}
+	err = cmd.Wait()
 
 	stdOutBytes := stdOutBuff.Bytes()
 	stdErrBytes := stdErrBuff.Bytes()
 	stdOut := strings.TrimSpace(string(stdOutBytes))
 	stdErr := strings.TrimSpace(string(stdErrBytes))
+
 	switch err.(type) {
 	case nil:
 		c.stdout = bytes.NewBuffer(stdOutBytes)
@@ -624,50 +650,9 @@ func (c *CLI) Outputs() (string, string, error) {
 	}
 }
 
-// Background executes the command in the background and returns the Cmd object
-// which may be killed later via cmd.Process.Kill().  It also returns buffers
-// holding the stdout & stderr of the command, which may be read from only after
-// calling cmd.Wait().
-func (c *CLI) Background() (*exec.Cmd, *bytes.Buffer, *bytes.Buffer, error) {
-	if c.verbose {
-		fmt.Printf("DEBUG: oc %s\n", c.printCmd())
-	}
-	cmd := exec.Command(c.execPath, c.finalArgs...)
-	cmd.Stdin = c.stdin
-	var stdout, stderr bytes.Buffer
-	cmd.Stdout = bufio.NewWriter(&stdout)
-	cmd.Stderr = bufio.NewWriter(&stderr)
-
-	framework.Logf("Running '%s %s'", c.execPath, strings.Join(c.finalArgs, " "))
-
-	err := cmd.Start()
-	return cmd, &stdout, &stderr, err
-}
-
-// BackgroundRC executes the command in the background and returns the Cmd
-// object which may be killed later via cmd.Process.Kill().  It returns a
-// ReadCloser for stdout.  If in doubt, use Background().  Consult the os/exec
-// documentation.
-func (c *CLI) BackgroundRC() (*exec.Cmd, io.ReadCloser, error) {
-	if c.verbose {
-		fmt.Printf("DEBUG: oc %s\n", c.printCmd())
-	}
-	cmd := exec.Command(c.execPath, c.finalArgs...)
-	cmd.Stdin = c.stdin
-	stdout, err := cmd.StdoutPipe()
-	if err != nil {
-		return nil, nil, err
-	}
-
-	framework.Logf("Running '%s %s'", c.execPath, strings.Join(c.finalArgs, " "))
-
-	err = cmd.Start()
-	return cmd, stdout, err
-}
-
 // OutputToFile executes the command and store output to a file
 func (c *CLI) OutputToFile(filename string) (string, error) {
-	content, err := c.Output()
+	content, _, err := c.Outputs()
 	if err != nil {
 		return "", err
 	}
@@ -852,3 +837,37 @@ func defaultClientTransport(rt http.RoundTripper) http.RoundTripper {
 	transport.MaxIdleConnsPerHost = 100
 	return transport
 }
+
+const (
+	installConfigName = "cluster-config-v1"
+)
+
+// installConfig The subset of openshift-install's InstallConfig we parse for this test
+type installConfig struct {
+	FIPS bool `json:"fips,omitempty"`
+}
+
+func IsFIPS(client clientcorev1.ConfigMapsGetter) (bool, error) {
+	// this currently uses an install config because it has a lower dependency threshold than going directly to the node.
+	installConfig, err := installConfigFromCluster(client)
+	if err != nil {
+		return false, err
+	}
+	return installConfig.FIPS, nil
+}
+
+func installConfigFromCluster(client clientcorev1.ConfigMapsGetter) (*installConfig, error) {
+	cm, err := client.ConfigMaps("kube-system").Get(context.Background(), installConfigName, metav1.GetOptions{})
+	if err != nil {
+		return nil, err
+	}
+	data, ok := cm.Data["install-config"]
+	if !ok {
+		return nil, fmt.Errorf("no install-config found in kube-system/%s", installConfigName)
+	}
+	config := &installConfig{}
+	if err := yaml.Unmarshal([]byte(data), config); err != nil {
+		return nil, err
+	}
+	return config, nil
+}
